"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logout = exports.login = exports.register = void 0;
const user_record_1 = require("../records/user.record");
const bcryptjs_1 = __importDefault(require("bcryptjs"));
const errors_1 = require("../utils/errors");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const config_1 = require("../config/config");
const register = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const users = yield user_record_1.UserRecord.getAllUsers();
        const checkEmail = users.some(user => user.email === req.body.email);
        if (checkEmail) {
            res.send(`Rejestracja nie powiodła się, ponieważ konto dla adresu email: "${req.body.email}" jest już założone w serwisie.`);
            throw new errors_1.ValidationError(`Konto dla adresu email: "${req.body.email}" jest już założone w serwisie.`);
        }
        const salt = bcryptjs_1.default.genSaltSync(10);
        const hash = bcryptjs_1.default.hashSync(req.body.pwd, salt);
        const newUser = new user_record_1.UserRecord({
            email: req.body.email,
            hashPwd: hash,
            phoneNum: req.body.phoneNum,
            address: req.body.address,
            lat: req.body.lat,
            lon: req.body.lon,
        });
        yield newUser.insert();
        res.status(201).send(`Konto dla użytkownika "${req.body.email}" zostało utworzone. Zaloguj się, aby korzystać z aplikacji.`);
    }
    catch (err) {
        next(err);
    }
});
exports.register = register;
const login = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield user_record_1.UserRecord.getOneUserByEmail(req.body.email);
        if (!user) {
            res.send({
                info: `W serwisie nie ma założonego konta dla adresu email: "${req.body.email}"`,
            });
            throw new errors_1.ValidationError(`W serwisie nie ma założonego konta dla adresu email: "${req.body.email}"`);
        }
        const isPassCorrect = yield bcryptjs_1.default.compare(req.body.pwd, user.hashPwd);
        if (!isPassCorrect) {
            res.send({
                info: 'Logowanie nie powiodło się. Hasło jest nieprawidłowo.',
            });
            throw new errors_1.ValidationError(`Hasło jest nieprawidłowe.`);
        }
        const token = jsonwebtoken_1.default.sign({ id: user.id, role: user.role, email: user.email }, config_1.config.secretKey);
        yield user.updateOne(user.id, token);
        const { hashPwd, currentTokenId } = user, otherDetails = __rest(user, ["hashPwd", "currentTokenId"]);
        res
            .cookie('access_token', token, {
            secure: true,
            domain: config_1.config.domain,
            httpOnly: true,
        })
            .status(200)
            .send(Object.assign(Object.assign({}, otherDetails), { info: 'Jesteś zalogowany. Zapraszamy do korzsytania z aplikacji.' }));
    }
    catch (err) {
        next(err);
    }
});
exports.login = login;
const logout = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        // @ts-ignore
        const user = yield user_record_1.UserRecord.getOneUserByEmail(req.user.email);
        // @ts-ignore
        yield user.updateOne(req.user.id, null);
        res.clearCookie("access_token", {
            secure: false,
            domain: config_1.config.domain,
            httpOnly: true,
        });
        res.send('Użytkownik zostal wylogowany.');
    }
    catch (err) {
        next(err);
    }
});
exports.logout = logout;
//# sourceMappingURL=auth.controller.js.map