"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteOneCar = exports.getAllCars = exports.getUsersCars = exports.getOneCarById = exports.getSearchCars = exports.addCar = void 0;
const car_record_1 = require("../records/car.record");
const user_record_1 = require("../records/user.record");
const addCar = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield user_record_1.UserRecord.getOneUserById(req.params.id);
        const cityName = user.address.split(',')[0];
        const newCar = new car_record_1.CarRecord({
            bodyStyle: req.body.bodyStyle,
            brand: req.body.brand,
            model: req.body.model,
            price: req.body.price,
            year: req.body.year,
            distance: req.body.distance,
            fuelType: req.body.fuelType,
            userId: req.params.id,
            city: cityName,
            profilePhotoUrl: req.body.profilePhotoUrl,
        });
        yield newCar.insert();
        res.status(201).send(`Samochód ${req.body.brand} ${req.body.model} został dodany.`);
    }
    catch (err) {
        res.send('Przepraszamy, nie udało sie dodać ogłoszenia. Spróbuj za jakiś czas...');
        next(err);
    }
});
exports.addCar = addCar;
const getSearchCars = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { bodyStyle, brand, model, priceStart, priceEnd, yearStart, yearEnd, fuelType, distanceStart, distanceEnd } = req.body;
        const cars = yield car_record_1.CarRecord.getSearchCars(bodyStyle, brand, model, priceStart, priceEnd, yearStart, yearEnd, fuelType, distanceStart, distanceEnd);
        res.status(200).send(cars);
    }
    catch (err) {
        next(err);
    }
});
exports.getSearchCars = getSearchCars;
const getOneCarById = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const car = yield car_record_1.CarRecord.getOneCarById(req.params.id);
        res.status(200).send(car);
    }
    catch (err) {
        next(err);
    }
});
exports.getOneCarById = getOneCarById;
const getUsersCars = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const cars = yield car_record_1.CarRecord.getUsersCars(req.params.id);
        res.status(200).send(cars);
    }
    catch (err) {
        next(err);
    }
});
exports.getUsersCars = getUsersCars;
const getAllCars = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const cars = yield car_record_1.CarRecord.getAllCars();
        res.status(200).send(cars);
    }
    catch (err) {
        next(err);
    }
});
exports.getAllCars = getAllCars;
const deleteOneCar = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const carToDelete = yield car_record_1.CarRecord.getOneCarById(req.params.carId);
        if (!carToDelete) {
            res.status(200).send('Nie ma takiego ogłoszenia.');
            return;
        }
        yield car_record_1.CarRecord.deleteOneCar(req.params.carId);
        res.status(200).send(`Ogłoszenie samochodu "${carToDelete.brand} ${carToDelete.model}" zostało usunięte.`);
    }
    catch (err) {
        next(err);
    }
});
exports.deleteOneCar = deleteOneCar;
//# sourceMappingURL=car.controller.js.map