"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const dotenv_1 = __importDefault(require("dotenv"));
const cors_1 = __importDefault(require("cors"));
require("express-async-errors");
const errors_1 = require("./utils/errors");
const cookie_parser_1 = __importDefault(require("cookie-parser"));
const auth_router_1 = require("./routes/auth.router");
const cars_router_1 = require("./routes/cars.router");
const images_router_1 = require("./routes/images.router");
const users_router_1 = require("./routes/users.router");
const config_1 = require("./config/config");
const watch_router_1 = require("./routes/watch.router");
const app = (0, express_1.default)();
dotenv_1.default.config();
app.use((0, cors_1.default)({
    origin: config_1.config.corsOrigin,
    credentials: true,
}));
app.use((0, cookie_parser_1.default)());
app.use(express_1.default.json());
app.use('/api/auth', auth_router_1.authRouter);
app.use('/api/cars', cars_router_1.carsRouter);
app.use('/api/images', images_router_1.imagesRouter);
app.use('/api/users', users_router_1.usersRouter);
app.use('/api/watch', watch_router_1.watchRouter);
app.use(errors_1.handleError);
app.listen(3001, '0.0.0.0', () => {
    console.log('Listening on http://localhost:3001');
});
//# sourceMappingURL=index.js.map