"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CarRecord = void 0;
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class CarRecord {
    constructor(obj) {
        if (!obj.bodyStyle || obj.bodyStyle.length > 12) {
            throw new errors_1.ValidationError('Typ nadwozia nie może mieć więcej niż 12 znaków.');
        }
        if (!obj.brand || obj.brand.length > 255) {
            throw new errors_1.ValidationError('Marka nie może mieć więcej niż 255 znaków.');
        }
        if (!obj.model || obj.model.length > 255) {
            throw new errors_1.ValidationError('Model nie może mieć więcej niż 255 znaków.');
        }
        if (!obj.price || String(obj.price).length > 11) {
            throw new errors_1.ValidationError('Cena nie może mieć więcej niż 11 cyfr');
        }
        if (!obj.year || obj.year < 0 || obj.year > 9999) {
            throw new errors_1.ValidationError('Rok produkcji musi znajdować się w przedziale od 0 do 9999');
        }
        if (!obj.distance || String(obj.distance).length > 11) {
            throw new errors_1.ValidationError('Przebieg nie może mieć więcej niż 11 cyfr');
        }
        if (!obj.fuelType || obj.fuelType.length > 20) {
            throw new errors_1.ValidationError('Typ paliwa nie może mieć więcej niz 20 znaków');
        }
        if (!obj.city || obj.city.length > 255) {
            throw new errors_1.ValidationError('Nazwa miasta nie może mieć więcej niż 255 znaków.');
        }
        if (!obj.profilePhotoUrl || obj.profilePhotoUrl.length > 255) {
            throw new errors_1.ValidationError('Adres URL do zdjęcia nie może mieć więcej niż 255 znaków.');
        }
        this.id = obj.id;
        this.bodyStyle = obj.bodyStyle;
        this.brand = obj.brand;
        this.model = obj.model;
        this.price = obj.price;
        this.year = obj.year;
        this.distance = obj.distance;
        this.fuelType = obj.fuelType;
        this.userId = obj.userId;
        this.city = obj.city;
        this.profilePhotoUrl = obj.profilePhotoUrl;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `cars` VALUES (:id, :bodyStyle, :brand, :model, :price, :year, :distance, :fuelType, :userId, :city, :profilePhotoUrl)", {
                id: this.id,
                bodyStyle: this.bodyStyle,
                brand: this.brand,
                model: this.model,
                price: this.price,
                year: this.year,
                distance: this.distance,
                fuelType: this.fuelType,
                userId: this.userId,
                city: this.city,
                profilePhotoUrl: this.profilePhotoUrl,
            });
            return this.id;
        });
    }
    static getSearchCars(bodyStyle, brand, model, priceStart, priceEnd, yearStart, yearEnd, fuelType, distanceStart, distanceEnd) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `cars` WHERE `bodyStyle` LIKE :bodyStyle AND `brand` LIKE :brand AND `model` LIKE :model AND `price` >= :priceStart AND `price` <= :priceEnd AND `year` >= :yearStart AND `year` <= :yearEnd AND `fuelType` LIKE :fuelType AND `distance` >= :distanceStart AND `distance` <= :distanceEnd", {
                bodyStyle,
                brand,
                model,
                priceStart,
                priceEnd,
                yearStart,
                yearEnd,
                fuelType,
                distanceStart,
                distanceEnd,
            });
            return results.map(car => new CarRecord(car));
        });
    }
    static getOneCarById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `cars` WHERE `id` = :id", {
                id,
            });
            return new CarRecord(results[0]);
        });
    }
    static getUsersCars(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `cars` WHERE `userId` = :id", {
                id,
            });
            return results.map(car => new CarRecord(car));
        });
    }
    static getAllCars() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `cars`");
            return results.map(car => new CarRecord(car));
        });
    }
    static deleteOneCar(carId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `cars` WHERE id = :carId", {
                carId,
            });
        });
    }
}
exports.CarRecord = CarRecord;
//# sourceMappingURL=car.record.js.map