"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageRecord = void 0;
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class ImageRecord {
    constructor(obj) {
        if (!obj.url || obj.url.length > 255) {
            throw new errors_1.ValidationError('Adres url nie może zawierać więcej niż 255 znaków');
        }
        this.id = obj.id;
        this.url = obj.url;
        this.carId = obj.carId;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `images` VALUES(:id, :url, :carId)", {
                id: this.id,
                url: this.url,
                carId: this.carId,
            });
            return this.id;
        });
    }
    static getImagesByCarId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `images` WHERE `carId` = :id", {
                id,
            });
            return results.map(image => new ImageRecord(image));
        });
    }
}
exports.ImageRecord = ImageRecord;
//# sourceMappingURL=image.record.js.map