"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class UserRecord {
    constructor(obj) {
        if (!obj.email || obj.email.length > 255) {
            throw new errors_1.ValidationError('Email musi zawierać znak @, oraz nie może mieć więcej niż 255 znaków.');
        }
        if (!obj.phoneNum || String(obj.phoneNum).length > 9) {
            throw new errors_1.ValidationError('Numer telefonu nie może przekraczać 9 cyfr.');
        }
        if (!obj.address || obj.address.length > 255) {
            throw new errors_1.ValidationError('Adres nie może przekraczać 255 znaków.');
        }
        if (typeof obj.lon !== 'number' || typeof obj.lat !== 'number') {
            throw new errors_1.ValidationError('Nie można zlokalizować ogłoszenia.');
        }
        this.id = obj.id;
        this.email = obj.email;
        this.hashPwd = obj.hashPwd;
        this.role = obj.role;
        this.phoneNum = obj.phoneNum;
        this.address = obj.address;
        this.lat = obj.lat;
        this.lon = obj.lon;
        this.currentTokenId = obj.currentTokenId;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
                this.role = 'USER';
                this.currentTokenId = null;
            }
            else {
                throw new errors_1.ValidationError('Ten użytkownik jest już zarejestrowany.');
            }
            yield db_1.pool.execute("INSERT INTO `users` VALUES (:id, :email, :hashPwd, :role, :phoneNum, :address, :lat, :lon, :currentTokenId)", {
                id: this.id,
                email: this.email,
                hashPwd: this.hashPwd,
                role: this.role,
                phoneNum: this.phoneNum,
                address: this.address,
                lat: this.lat,
                lon: this.lon,
                currentTokenId: this.currentTokenId,
            });
            return this.id;
        });
    }
    updateOne(id, token) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `users` SET `currentTokenId` = :token WHERE `id` = :id", {
                id,
                token,
            });
        });
    }
    static getAllUsers() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users`");
            return results.map(user => new UserRecord(user));
        });
    }
    static getOneUserByEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `email` = :email", {
                email,
            });
            return results.length > 0 ? new UserRecord(results[0]) : null;
        });
    }
    static getOneUserById(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `users` WHERE `id` = :id", {
                id,
            });
            return new UserRecord(results[0]);
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map