"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WatchRecord = void 0;
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class WatchRecord {
    constructor(obj) {
        this.id = obj.id;
        this.userId = obj.userId;
        this.carId = obj.carId;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `watch` VALUES(:id, :userId, :carId)", {
                id: this.id,
                userId: this.userId,
                carId: this.carId,
            });
            return this.id;
        });
    }
    static getOneWatchByUserIdAndCarId(userId, carId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `watch` WHERE `userId` = :userId AND `carId` = :carId", {
                userId,
                carId,
            });
            return results.length > 0 ? new WatchRecord(results[0]) : null;
        });
    }
    static getAllWatchByUserId(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `watch` WHERE `userId` = :userId", {
                userId,
            });
            return results.map(watch => new WatchRecord(watch));
        });
    }
    deleteOneWatch(userId, carId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `watch` WHERE `userId` = :userId AND `carId` = :carId", {
                userId,
                carId,
            });
        });
    }
}
exports.WatchRecord = WatchRecord;
//# sourceMappingURL=watch.record.js.map